@@ -12,16 +12,15 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-// copied from github.com/operator-framework/operator-sdk/internal/helm/client
-
 package client
 
 import (
 	"errors"
 	"io"
+	"strings"
 
+	"github.com/open-cluster-management/multicloud-operators-subscription-release/pkg/internal/util/k8sutil"
 	"github.com/operator-framework/operator-lib/handler"
-	"github.com/stolostron/multicloud-operators-subscription-release/pkg/internal/util/k8sutil"
 	"helm.sh/helm/v3/pkg/kube"
 	"k8s.io/apimachinery/pkg/api/meta"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
@@ -146,7 +145,9 @@ func (c *ownerRefInjectingClient) Build(reader io.Reader, validate bool) (kube.R
 			return err
 		}
 
-		if useOwnerRef {
+		// If the resource contains the Helm resource-policy keep annotation, then do not add
+		// the owner reference. So when the CR is deleted, Kubernetes won't GCs the resource.
+		if useOwnerRef && !containsResourcePolicyKeep(u.GetAnnotations()) {
 			ownerRef := metav1.NewControllerRef(c.owner, c.owner.GroupVersionKind())
 			u.SetOwnerReferences([]metav1.OwnerReference{*ownerRef})
 		} else {
@@ -162,3 +163,15 @@ func (c *ownerRefInjectingClient) Build(reader io.Reader, validate bool) (kube.R
 	}
 	return resourceList, nil
 }
+
+func containsResourcePolicyKeep(annotations map[string]string) bool {
+	if annotations == nil {
+		return false
+	}
+	resourcePolicyType, ok := annotations[kube.ResourcePolicyAnno]
+	if !ok {
+		return false
+	}
+	resourcePolicyType = strings.ToLower(strings.TrimSpace(resourcePolicyType))
+	return resourcePolicyType == kube.KeepPolicy
+}
