@@ -45,9 +45,9 @@ import (
 	"sigs.k8s.io/controller-runtime/pkg/reconcile"
 	"sigs.k8s.io/controller-runtime/pkg/source"
 
-	appv1 "github.com/stolostron/multicloud-operators-subscription-release/pkg/apis/apps/v1"
-	"github.com/stolostron/multicloud-operators-subscription-release/pkg/release"
-	helmoperator "github.com/stolostron/multicloud-operators-subscription-release/pkg/release"
+	appv1 "github.com/open-cluster-management/multicloud-operators-subscription-release/pkg/apis/apps/v1"
+	"github.com/open-cluster-management/multicloud-operators-subscription-release/pkg/release"
+	helmoperator "github.com/open-cluster-management/multicloud-operators-subscription-release/pkg/release"
 )
 
 const (
@@ -130,8 +130,15 @@ func (r *ReconcileHelmRelease) Reconcile(request reconcile.Request) (reconcile.R
 		return reconcile.Result{}, err
 	}
 
+	if instance.Repo.Source == nil {
+		klog.Error("Failed to detect Repo.Source from HelmRelease ", helmreleaseNsn(instance), ". Setting requeue to false.")
+		//TODO set error status here
+
+		return reconcile.Result{Requeue: false}, nil
+	}
+
 	// setting the nil spec to "":"" allows helmrelease to reconcile with default chart values.
-	if instance.Spec == nil {
+	if instance.Spec == nil && instance.GetDeletionTimestamp() == nil {
 		spec := make(map[string]interface{})
 
 		err := yaml.Unmarshal([]byte("{\"\":\"\"}"), &spec)
@@ -551,7 +558,12 @@ func (r *ReconcileHelmRelease) uninstall(instance *appv1.HelmRelease, manager he
 				klog.Error("Errors caught while trying to delete resources ", joinErrors(errs))
 			}
 
-			message := "Failed to delete HelmRelease due to resource: " +
+			gvk := ""
+			if resource.Mapping != nil {
+				gvk = resource.Mapping.GroupVersionKind.String()
+			}
+
+			message := "Failed to delete HelmRelease due to resource: " + gvk + " " +
 				resource.Namespace + "/" + resource.Name +
 				" is not deleted yet. Checking again after one minute."
 			klog.Error(message)
