@@ -31,7 +31,7 @@ import (
 	"helm.sh/helm/v3/pkg/storage"
 	"helm.sh/helm/v3/pkg/storage/driver"
 
-	appv1 "github.com/stolostron/multicloud-operators-subscription-release/pkg/apis/apps/v1"
+	appv1 "github.com/open-cluster-management/multicloud-operators-subscription-release/pkg/apis/apps/v1"
 )
 
 // Manager manages a Helm release. It can install, upgrade, reconcile,
@@ -195,17 +195,13 @@ func (m manager) UpgradeRelease(ctx context.Context, opts ...UpgradeOption) (*rp
 
 // UninstallRelease performs a Helm release uninstall.
 func (m manager) UninstallRelease(ctx context.Context, opts ...UninstallOption) (*rpb.Release, error) {
-	// Get history of this release
-	if _, err := m.storageBackend.History(m.releaseName); err != nil {
-		return nil, fmt.Errorf("failed to get release history: %w", err)
-	}
-
 	uninstall := action.NewUninstall(m.actionConfig)
 	for _, o := range opts {
 		if err := o(uninstall); err != nil {
 			return nil, fmt.Errorf("failed to apply uninstall option: %w", err)
 		}
 	}
+
 	uninstallResponse, err := uninstall.Run(m.releaseName)
 	if uninstallResponse == nil {
 		return nil, err
